@@ -25,9 +25,9 @@ import java.io.File;
 import java.io.IOException;
 import java.lang.management.ManagementFactory;
 import java.nio.charset.StandardCharsets;
-import java.nio.file.Files;
 import java.sql.Connection;
 import java.sql.DatabaseMetaData;
+import java.time.Duration;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.HashMap;
@@ -35,6 +35,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Timer;
 import java.util.TimerTask;
+import java.util.Collections;
+import java.util.concurrent.ExecutionException;
 import java.util.stream.Collectors;
 
 import javax.management.AttributeNotFoundException;
@@ -84,11 +86,16 @@ import org.opennms.netmgt.dao.api.NotificationDao;
 import org.opennms.netmgt.dao.api.OutageDao;
 import org.opennms.netmgt.dao.api.ProvisiondConfigurationDao;
 import org.opennms.netmgt.dao.api.SnmpInterfaceDao;
+import org.opennms.netmgt.flows.api.FlowQueryService;
+import org.opennms.netmgt.flows.filter.api.Filter;
+import org.opennms.netmgt.flows.filter.api.TimeRangeFilter;
 import org.opennms.netmgt.model.OnmsMonitoringSystem;
 import org.opennms.netmgt.provision.persist.ForeignSourceRepository;
 import org.opennms.netmgt.provision.persist.foreignsource.ForeignSource;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
+import oshi.SystemInfo;
+import oshi.hardware.CentralProcessor;
 
 public class UsageStatisticsReporter implements StateChangeHandler {
     private static final Logger LOG = LoggerFactory.getLogger(UsageStatisticsReporter.class);
@@ -100,6 +107,7 @@ public class UsageStatisticsReporter implements StateChangeHandler {
     private static final String JMX_OBJ_OPENNMS_FLOWS_PERSISTED = "org.opennms.netmgt.flows:name=flowsPersisted,type=meters";
     private static final String JMX_OBJ_OPENNMS_REPO_SAMPLE_INSERTED = "org.opennms.newts:name=repository.samples-inserted,type=meters";
     private static final String JMX_OBJ_OPENNMS_QUEUED = "OpenNMS:Name=Queued";
+    private static final String JMX_OBJ_OPENNMS_TSS = "org.opennms.timeseries:name=samples.write.integration";
     private static final String JMX_ATTR_FREE_PHYSICAL_MEMORY_SIZE = "FreePhysicalMemorySize";
     private static final String JMX_ATTR_TOTAL_PHYSICAL_MEMORY_SIZE = "TotalPhysicalMemorySize";
     private static final String JMX_ATTR_AVAILABLE_PROCESSORS = "AvailableProcessors";
@@ -115,6 +123,10 @@ public class UsageStatisticsReporter implements StateChangeHandler {
     public static final String APPLIANCE_MINI_OID = ".1.3.6.1.4.1.5813.42.5.2";
     public static final String APPLIANCE_1U_OID = ".1.3.6.1.4.1.5813.42.5.3";
 
+    //could be made configurable in future
+    public static final int DEFAULT_ALERTS_LAST_HOURS = 24;
+    public static final int DEFAULT_EVENTS_LAST_HOURS = 24;
+
     private String m_url;
 
     private long m_interval;
@@ -167,6 +179,9 @@ public class UsageStatisticsReporter implements StateChangeHandler {
 
     private NotificationDao m_notificationDao;
 
+
+    private FlowQueryService flowQueryService;
+
     public synchronized void init() {
         if (m_timer != null) {
             LOG.warn("Usage statistic reporter was already initialized.");
@@ -255,6 +270,8 @@ public class UsageStatisticsReporter implements StateChangeHandler {
             LOG.warn("An error occurred while retrieving the system id. " +
                         "The usage report will be submitted with a null system id.", e);
         }
+
+        usageStatisticsReport.setFlowCountPerSecond(getFlowCount());
         // Operating System
         usageStatisticsReport.setOsName(System.getProperty("os.name"));
         usageStatisticsReport.setOsArch(System.getProperty("os.arch"));
@@ -269,7 +286,9 @@ public class UsageStatisticsReporter implements StateChangeHandler {
         usageStatisticsReport.setSnmpInterfacesWithFlows(m_snmpInterfaceDao.getNumInterfacesWithFlows());
         usageStatisticsReport.setMonitoredServices(m_monitoredServiceDao.countAll());
         usageStatisticsReport.setEvents(m_eventDao.countAll());
+        usageStatisticsReport.setEventsLastHours(m_eventDao.getNumEventsLastHours(DEFAULT_EVENTS_LAST_HOURS));
         usageStatisticsReport.setAlarms(m_alarmDao.countAll());
+        usageStatisticsReport.setAlarmsLastHours(m_alarmDao.getNumAlarmsLastHours(DEFAULT_ALERTS_LAST_HOURS));
         usageStatisticsReport.setSituations(m_alarmDao.getNumSituations());
         usageStatisticsReport.setMonitoringLocations(m_monitoringLocationDao.countAll());
         usageStatisticsReport.setMinions(m_monitoringSystemDao.getNumMonitoringSystems(OnmsMonitoringSystem.TYPE_MINION));
@@ -310,6 +329,25 @@ public class UsageStatisticsReporter implements StateChangeHandler {
         return usageStatisticsReport;
     }
 
+    private long getFlowCount() {
+
+        long flowCount = 0;
+
+        if(flowQueryService != null) {
+            try {
+                final long currentTime = System.currentTimeMillis();
+                final long twentyFourHoursAgo = currentTime - Duration.ofHours(24).toMillis();
+                final List<Filter> filters = Collections.singletonList(new TimeRangeFilter(twentyFourHoursAgo, currentTime));
+                flowCount = flowQueryService.getFlowCount(filters).get();
+
+            } catch (Exception e) {
+                LOG.warn("An error occurred while retrieving the flow count.", e);
+            }
+        }
+
+        return flowCount;
+    }
+
     private boolean isContainerized() {
         // this will detect podman even in custom container builds
         final boolean inPodman = new File("/run/.containerenv").exists();
@@ -339,6 +377,28 @@ public class UsageStatisticsReporter implements StateChangeHandler {
         if (availableProcessorsObj != null) {
             usageStatisticsReport.setAvailableProcessors((int) availableProcessorsObj);
         }
+
+        //populating current system cpu utilization
+        SystemInfo systemInfo = new SystemInfo();
+        CentralProcessor processor = systemInfo.getHardware().getProcessor();
+
+        double cpuLoad =  processor.getSystemCpuLoad(1000) * 100;
+        usageStatisticsReport.setCpuUtilization(String.format("%.2f%%", cpuLoad));
+
+        Object totalPhysicalMemorySizeObj = getJmxAttribute(JMX_OBJ_OS, JMX_ATTR_TOTAL_PHYSICAL_MEMORY_SIZE);
+        if (totalPhysicalMemorySizeObj != null) {
+            long totalMemory = (long)totalPhysicalMemorySizeObj;
+            if (totalMemory == 0) {
+                usageStatisticsReport.setMemoryUtilization("0%");
+            } else {
+                Object freePhysicalMemorySizeObj = getJmxAttribute(JMX_OBJ_OS, JMX_ATTR_FREE_PHYSICAL_MEMORY_SIZE);
+                if (freePhysicalMemorySizeObj != null) {
+                    long freeMemory = (long) freePhysicalMemorySizeObj;
+                    double utilizedMemory = ((double) (totalMemory - freeMemory) / totalMemory) * 100;
+                    usageStatisticsReport.setMemoryUtilization(String.format("%.2f%%", utilizedMemory));
+                }
+            }
+        }
     }
 
     private void setOpenNmsJmxAttributes(UsageStatisticsReportDTO usageStatisticsReport) {
@@ -362,6 +422,10 @@ public class UsageStatisticsReporter implements StateChangeHandler {
         if (coreQueuedUpdatesCompletedObj != null) {
             usageStatisticsReport.setCoreQueuedUpdatesCompleted((long) coreQueuedUpdatesCompletedObj);
         }
+        Object coreTssWritesCompletedObj = getJmxAttribute(JMX_OBJ_OPENNMS_TSS, JMX_ATTR_COUNT);
+        if (coreTssWritesCompletedObj != null) {
+            usageStatisticsReport.setCoreTssWritesCompleted((long) coreTssWritesCompletedObj);
+        }
     }
 
     private Object getJmxAttribute(String objectName, String attributeName) {
@@ -645,6 +709,11 @@ public class UsageStatisticsReporter implements StateChangeHandler {
         this.m_deviceConfigDao = deviceConfigDao;
     }
 
+    public void setFlowQueryService(FlowQueryService flowQueryService) {
+        this.flowQueryService = flowQueryService;
+    }
+
+
     private int getDestinationPathCount(){
         try {
             return m_destinationPathFactory.getPaths().size();
